Sources the app's build_ui.R (root), which must define a build_ui()
function returning an htmltools tag, and writes the rendered HTML to
www/index.html via htmltools::save_html(). Author the layout with
bslib; ship static HTML.
Sources the app's build_ui.R (root), which must define a build_ui()
function returning an htmltools tag, and writes the rendered HTML to
www/index.html via htmltools::save_html(). Author the layout with
bslib; ship static HTML.