Read a dataset from a store, reloading if the file changed
Source:R/data-store.R
aurora_data_get.RdReturns the named dataset, re-reading from disk if its modification time has advanced since the last read (hot reload), otherwise returning the cached value.