Returns the payload if the signature is valid and the token has not expired;
otherwise NULL (never throws).
Arguments
- auth
An
aurora_auth_jwt()scheme.- token
The token string (e.g.
request$cookies$token).
Returns the payload if the signature is valid and the token has not expired;
otherwise NULL (never throws).
An aurora_auth_jwt() scheme.
The token string (e.g. request$cookies$token).